@@ -5,12 +5,13 @@ context("Test the simulate arguments")
 test_that("Argument dest works well", {
   model <- model_library$advan4_trans4
   
-  dataset <- Dataset()
-  dataset <- dataset %>% add(Bolus(time=0, amount=1000, compartment=1))
-  dataset <- dataset %>% add(Observations(times=seq(0,24, by=0.5)))
+  dataset <- Dataset() %>%
+    add(Bolus(time=0, amount=1000, compartment=1)) %>%
+    add(Observations(times=seq(0,24, by=0.5)))
   
   # Unknown engine
-  expect_error(model %>% simulate(dataset=dataset, dest="ENGINE3"), regexp="Argument 'dest' must be one of: 'RxODE', 'mrgsolve' or NULL")
+  expect_error(model %>% simulate(dataset=dataset, dest="ENGINE3"),
+               regexp="Argument 'dest' must be one of: 'rxode2', 'RxODE', 'mrgsolve' or NULL")
   
   # Default engine (RxODE)
   results <- model %>% simulate(dataset=dataset)
@@ -20,9 +21,9 @@ test_that("Argument dest works well", {
 test_that("Auto seed value vs fix seed + default engine", {
   model <- model_library$advan4_trans4
   
-  dataset <- Dataset()
-  dataset <- dataset %>% add(Bolus(time=0, amount=1000, compartment=1))
-  dataset <- dataset %>% add(Observations(times=seq(0,24, by=0.5)))
+  dataset <- Dataset() %>%
+    add(Bolus(time=0, amount=1000, compartment=1)) %>%
+    add(Observations(times=seq(0,24, by=0.5)))
   
   # Fix seed
   results1 <- model %>% simulate(dataset=dataset, seed=10)
